@@ -46,11 +46,21 @@ Regione Toscana - Settore Sistema Informativo Territoriale ed Ambientale
 #include <sqlite3.h>
 #include <spatialite.h>
 
+#if defined(_WIN32) && !defined(__MINGW32__)
+#include "config-msvc.h"
+#else
+#include "config.h"
+#endif
+
 #define ARG_NONE	0
 #define ARG_DB_PATH	1
 #define ARG_CACHE_SIZE 2
 #define ARG_NAME_LEVEL 3
 
+#ifdef _WIN32
+#define strcasecmp	_stricmp
+#endif /* not WIN32 */
+
 struct resultset_values
 {
 /* a struct wrapping values from a resultset */
@@ -1865,11 +1875,11 @@ spatialite_autocreate (sqlite3 * db)
 	return;
 
 /* all right, it's empty: proceding to initialize */
-    strcpy (sql, "SELECT InitSpatialMetadata(1)");
+    strcpy (sql, "SELECT InitSpatialMetadataFull(1)");
     ret = sqlite3_exec (db, sql, NULL, NULL, &err_msg);
     if (ret != SQLITE_OK)
       {
-	  fprintf (stderr, "InitSpatialMetadata() error: %s\n", err_msg);
+	  fprintf (stderr, "InitSpatialMetadataFull() error: %s\n", err_msg);
 	  sqlite3_free (err_msg);
 	  return;
       }
@@ -2037,6 +2047,19 @@ open_db (const char *path, sqlite3 ** handle, int cache_size, void *cache)
     return;
 }
 
+static void
+do_version ()
+{
+/* printing version infos */
+	fprintf( stderr, "\nVersion infos\n");
+	fprintf( stderr, "===========================================\n");
+    fprintf (stderr, "spatialite_osm_overpass: %s\n", VERSION);
+	fprintf (stderr, "target CPU ............: %s\n", spatialite_target_cpu ());
+    fprintf (stderr, "libspatialite .........: %s\n", spatialite_version ());
+    fprintf (stderr, "libsqlite3 ............: %s\n", sqlite3_libversion ());
+    fprintf (stderr, "\n");
+}
+
 static void
 do_help ()
 {
@@ -2046,6 +2069,7 @@ do_help ()
 	     "==============================================================\n");
     fprintf (stderr,
 	     "-h or --help                    print this help message\n");
+    fprintf (stderr, "-v or --version                 print version infos\n");
     fprintf (stderr,
 	     "-d or --db-path     pathname    the SpatiaLite DB path\n\n");
     fprintf (stderr, "you can specify the following options as well\n");
@@ -2112,6 +2136,12 @@ main (int argc, char *argv[])
 		do_help ();
 		return -1;
 	    }
+	  if (strcasecmp (argv[i], "--version") == 0
+	      || strcmp (argv[i], "-v") == 0)
+	    {
+		do_version ();
+		return -1;
+	    }
 	  if (strcmp (argv[i], "-d") == 0)
 	    {
 		next_arg = ARG_DB_PATH;
